Update ids in aedes_main table manually
Arguments
- update.serial_ids
Whether to update the serial_id column uniquely defining each row. This is off by default as the serial_id is auto-incremented by the server.
- update_dups
Whether to update rows with "duplicate" status (now the default) and also set the root_duplicated column.
- dry_run
Whether to show what would happen rather than doing it.
Value
Invisibly, a list describing what was (or, under dry_run, would be)
written: updated, a data frame of changed aedes_main rows (_id,
root_id, supervoxel_id, root_duplicated), and serial_ids, a data
frame of _id + newly assigned serial_id (or NULL when no serial ids
were assigned, e.g. the default update.serial_ids = FALSE).
Details
This is now part of the scripted updates on flyem but even in future it may occasionally be useful to trigger this manually.
Expert use only: there is a scheduled job that updates root IDs on FlyTable every 30 minutes, so this function should normally not be needed.
The root_duplicated column will only be ticked for root_ids when there is more than one entry after setting aside any rows with status=duplicate.