aedes_mirror() mirrors objects supported by nat::xform(), including
neurons, neuronlists, dotprops and coordinate matrices.
Arguments
- x
An object to mirror.
- method
Mirror method.
"tps"uses the bundledaedes_aedesSym_1000_tps.rdsregistration to map into Aedes symmetric space, flip across the X axis, then map back to original Aedes space."landmarks"uses paired landmarks in the original Aedes space.- units
Coordinate units for
xand the returned object. The symmetric registration is defined in microns; nm inputs are scaled before and after transformation.- subset
Optional subset passed to
nat::xform(), for example when transforming selected elements of a neuronlist.- landmarks
Optional landmark data with
pointAandpointBentries. WhenNULL, landmarks are read fromurlusingfafbseg::ngl_annotations().- raw
Whether landmark coordinates are in raw voxel space. When
FALSE, landmark coordinates are assumed to be inunits.- url
Neuroglancer URL containing paired mirror landmarks.
- vd
Optional voxel dimensions in nm. Advanced use; when
NULLandraw = TRUE, these are detected automatically.- ...
Additional arguments passed to
nat::xform().
Examples
if (FALSE) { # \dontrun{
sk <- with_aedes(fafbseg::read_l2skel(aedes_ids("class:DNa")[1]))
sk.mirror <- aedes_mirror(sk, units = "nm")
plot3d(sk, col = "grey")
plot3d(sk.mirror, col = "red", add = TRUE)
dps <- with_aedes(fafbseg::read_l2dp(aedes_ids("class:DNa")))
dps.mirror <- aedes_mirror(dps, units = "microns")
} # }