Update root_ids and supervoxel_ids from point information as necessary
Source:R/flytable.R
aedes_sequential_update.RdUpdate root_ids and supervoxel_ids from point information as necessary
Details
Note that point information will only be used if supervoxel information is missing. Therefore it is essential to delete supervoxel_id for any rows in which the point_xyz is changed.
By default root_ids are brought forward to the current segmentation state
(timestamp = 'now'). Callers may instead pin to a specific
materialisation version or timestamp.